-- Xbus 3.0.0-beta.14 database, the starting point for migrations

--
-- Name: account; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.account (
    type character varying(255) NOT NULL,
    csr text NOT NULL,
    cert text NOT NULL,
    id uuid NOT NULL,
    name character varying(255) NOT NULL,
    status character varying(255) NOT NULL,
    api_key character varying(255) NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone
);


--
-- Name: actor; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.actor (
    unresponsive boolean NOT NULL,
    id uuid NOT NULL,
    updated_at timestamp without time zone,
    name character varying(255) NOT NULL,
    role character varying(255) NOT NULL,
    status character varying(255) NOT NULL,
    online boolean NOT NULL,
    created_at timestamp without time zone NOT NULL,
    account_id uuid,
    kind character varying(255) NOT NULL,
    last_seen timestamp without time zone NOT NULL,
    config character varying(255) NOT NULL
);


--
-- Name: envelope; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.envelope (
    types_known boolean NOT NULL,
    status character varying(255) NOT NULL,
    error character varying(255) NOT NULL,
    id uuid NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone
);


--
-- Name: event; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.event (
    checksum bigint NOT NULL,
    validator character varying(255) NOT NULL,
    id bigint NOT NULL,
    envelope_id uuid NOT NULL,
    event_id uuid NOT NULL,
    event_type character varying(255) NOT NULL,
    status character varying(255) NOT NULL,
    item_count bigint NOT NULL
);


--
-- Name: event_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.event_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: event_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.event_id_seq OWNED BY public.event.id;


--
-- Name: graph; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.graph (
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone,
    name character varying(255) NOT NULL,
    version character varying(255) NOT NULL,
    status character varying(255) NOT NULL,
    edges text NOT NULL,
    id uuid NOT NULL
);


--
-- Name: graph_node; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.graph_node (
    role_broadcast boolean NOT NULL,
    source_match_event_types character varying(255) NOT NULL,
    outputs text NOT NULL,
    graph_id uuid NOT NULL,
    roles character varying(255) NOT NULL,
    type character varying(255) NOT NULL,
    actor_ids character varying(255) NOT NULL,
    actors character varying(255) NOT NULL,
    inputs text NOT NULL,
    id bigint NOT NULL,
    node_id character varying(255) NOT NULL
);


--
-- Name: graph_node_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.graph_node_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: graph_node_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.graph_node_id_seq OWNED BY public.graph_node.id;


--
-- Name: item; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.item (
    index_ bigint NOT NULL,
    data bytea NOT NULL,
    id bigint NOT NULL,
    event_id bigint NOT NULL,
    batch bigint NOT NULL
);


--
-- Name: item_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.item_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: item_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.item_id_seq OWNED BY public.item.id;


--
-- Name: job; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.job (
    status character varying(255) NOT NULL,
    id bigint NOT NULL,
    process_id uuid NOT NULL,
    actor_id uuid NOT NULL,
    node_id character varying(255) NOT NULL,
    detached boolean NOT NULL
);


--
-- Name: job_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.job_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: job_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.job_id_seq OWNED BY public.job.id;


--
-- Name: log_entry; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.log_entry (
    actor_id uuid,
    process_id uuid,
    node_id character varying(255) NOT NULL,
    "time" timestamp without time zone NOT NULL,
    level character varying(255) NOT NULL,
    text text NOT NULL,
    id bigint NOT NULL,
    envelope_id uuid
);


--
-- Name: log_entry_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.log_entry_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: log_entry_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.log_entry_id_seq OWNED BY public.log_entry.id;


--
-- Name: process; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.process (
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone,
    trigger_emitter_id uuid NOT NULL,
    trigger_envelope_id uuid NOT NULL,
    graph_id uuid NOT NULL,
    source_node_id character varying(255) NOT NULL,
    source_slot_id character varying(255) NOT NULL,
    id uuid NOT NULL
);


--
-- Name: process_log_entry; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.process_log_entry (
    id bigint NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    process_id uuid NOT NULL,
    data text NOT NULL,
    log_processed boolean NOT NULL,
    processing_error boolean NOT NULL
);


--
-- Name: process_log_entry_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.process_log_entry_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: process_log_entry_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.process_log_entry_id_seq OWNED BY public.process_log_entry.id;


--
-- Name: process_state; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.process_state (
    process_id uuid NOT NULL,
    status character varying(255) NOT NULL,
    status_reason text NOT NULL,
    node_states_changed timestamp without time zone NOT NULL,
    pm_level character varying(255) NOT NULL,
    pm_comment character varying(255) NOT NULL,
    pm_changed timestamp without time zone NOT NULL,
    status_changed timestamp without time zone NOT NULL,
    node_states text NOT NULL,
    pm_status character varying(255) NOT NULL
);


--
-- Name: route; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.route (
    process_id uuid NOT NULL,
    source text NOT NULL,
    envelope_id uuid NOT NULL,
    id bigint NOT NULL
);


--
-- Name: route_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.route_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: route_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.route_id_seq OWNED BY public.route.id;


--
-- Name: route_target; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.route_target (
    id bigint NOT NULL,
    route_id bigint NOT NULL,
    actor_id uuid NOT NULL,
    node_id character varying(255) NOT NULL,
    input character varying(255) NOT NULL
);


--
-- Name: route_target_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.route_target_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: route_target_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.route_target_id_seq OWNED BY public.route_target.id;


--
-- Name: event id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.event ALTER COLUMN id SET DEFAULT nextval('public.event_id_seq'::regclass);


--
-- Name: graph_node id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.graph_node ALTER COLUMN id SET DEFAULT nextval('public.graph_node_id_seq'::regclass);


--
-- Name: item id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.item ALTER COLUMN id SET DEFAULT nextval('public.item_id_seq'::regclass);


--
-- Name: job id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.job ALTER COLUMN id SET DEFAULT nextval('public.job_id_seq'::regclass);


--
-- Name: log_entry id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.log_entry ALTER COLUMN id SET DEFAULT nextval('public.log_entry_id_seq'::regclass);


--
-- Name: process_log_entry id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process_log_entry ALTER COLUMN id SET DEFAULT nextval('public.process_log_entry_id_seq'::regclass);


--
-- Name: route id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route ALTER COLUMN id SET DEFAULT nextval('public.route_id_seq'::regclass);


--
-- Name: route_target id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route_target ALTER COLUMN id SET DEFAULT nextval('public.route_target_id_seq'::regclass);


--
-- Name: account account_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account
    ADD CONSTRAINT account_pkey PRIMARY KEY (id);


--
-- Name: actor actor_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.actor
    ADD CONSTRAINT actor_pkey PRIMARY KEY (id);


--
-- Name: envelope envelope_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.envelope
    ADD CONSTRAINT envelope_pkey PRIMARY KEY (id);


--
-- Name: event event_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.event
    ADD CONSTRAINT event_pkey PRIMARY KEY (id);


--
-- Name: graph_node graph_node_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.graph_node
    ADD CONSTRAINT graph_node_pkey PRIMARY KEY (id);


--
-- Name: graph graph_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.graph
    ADD CONSTRAINT graph_pkey PRIMARY KEY (id);


--
-- Name: item item_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.item
    ADD CONSTRAINT item_pkey PRIMARY KEY (id);


--
-- Name: job job_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.job
    ADD CONSTRAINT job_pkey PRIMARY KEY (id);


--
-- Name: log_entry log_entry_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.log_entry
    ADD CONSTRAINT log_entry_pkey PRIMARY KEY (id);


--
-- Name: process_log_entry process_log_entry_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process_log_entry
    ADD CONSTRAINT process_log_entry_pkey PRIMARY KEY (id);


--
-- Name: process process_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process
    ADD CONSTRAINT process_pkey PRIMARY KEY (id);


--
-- Name: process_state process_state_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process_state
    ADD CONSTRAINT process_state_pkey PRIMARY KEY (process_id);


--
-- Name: route route_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route
    ADD CONSTRAINT route_pkey PRIMARY KEY (id);


--
-- Name: route_target route_target_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route_target
    ADD CONSTRAINT route_target_pkey PRIMARY KEY (id);


--
-- Name: account u_account_name; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account
    ADD CONSTRAINT u_account_name UNIQUE (name);


--
-- Name: actor u_actor_name; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.actor
    ADD CONSTRAINT u_actor_name UNIQUE (name);


--
-- Name: event u_event_envelope_id_event_id; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.event
    ADD CONSTRAINT u_event_envelope_id_event_id UNIQUE (envelope_id, event_id);


--
-- Name: graph u_graph_name_version; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.graph
    ADD CONSTRAINT u_graph_name_version UNIQUE (name, version);


--
-- Name: graph_node u_graph_node_graph_id_node_id; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.graph_node
    ADD CONSTRAINT u_graph_node_graph_id_node_id UNIQUE (graph_id, node_id);


--
-- Name: job u_job_process_id_actor_id_node_id; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.job
    ADD CONSTRAINT u_job_process_id_actor_id_node_id UNIQUE (process_id, actor_id, node_id);


--
-- Name: route u_route_process_id_source_envelope_id; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route
    ADD CONSTRAINT u_route_process_id_source_envelope_id UNIQUE (process_id, source, envelope_id);


--
-- Name: route_target u_route_target_route_id_actor_id_node_id_input; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route_target
    ADD CONSTRAINT u_route_target_route_id_actor_id_node_id_input UNIQUE (route_id, actor_id, node_id, input);


--
-- Name: i_envelope_id_actor_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX i_envelope_id_actor_id ON public.log_entry USING btree (envelope_id, actor_id);


--
-- Name: i_event_id_index_; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX i_event_id_index_ ON public.item USING btree (event_id, index_);


--
-- Name: i_process_id_level; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX i_process_id_level ON public.log_entry USING btree (process_id, level);


--
-- Name: actor actor_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.actor
    ADD CONSTRAINT actor_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE SET NULL;


--
-- Name: event event_envelope_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.event
    ADD CONSTRAINT event_envelope_id_fkey FOREIGN KEY (envelope_id) REFERENCES public.envelope(id) ON DELETE CASCADE;


--
-- Name: graph_node graph_node_graph_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.graph_node
    ADD CONSTRAINT graph_node_graph_id_fkey FOREIGN KEY (graph_id) REFERENCES public.graph(id);


--
-- Name: item item_event_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.item
    ADD CONSTRAINT item_event_id_fkey FOREIGN KEY (event_id) REFERENCES public.event(id) ON DELETE CASCADE;


--
-- Name: log_entry log_entry_actor_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.log_entry
    ADD CONSTRAINT log_entry_actor_id_fkey FOREIGN KEY (actor_id) REFERENCES public.actor(id);


--
-- Name: log_entry log_entry_envelope_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.log_entry
    ADD CONSTRAINT log_entry_envelope_id_fkey FOREIGN KEY (envelope_id) REFERENCES public.envelope(id);


--
-- Name: process_log_entry process_log_entry_process_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process_log_entry
    ADD CONSTRAINT process_log_entry_process_id_fkey FOREIGN KEY (process_id) REFERENCES public.process(id) ON DELETE CASCADE;


--
-- Name: process_state process_state_process_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process_state
    ADD CONSTRAINT process_state_process_id_fkey FOREIGN KEY (process_id) REFERENCES public.process(id) ON DELETE CASCADE;


--
-- Name: process process_trigger_emitter_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process
    ADD CONSTRAINT process_trigger_emitter_id_fkey FOREIGN KEY (trigger_emitter_id) REFERENCES public.actor(id);


--
-- Name: process process_trigger_envelope_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.process
    ADD CONSTRAINT process_trigger_envelope_id_fkey FOREIGN KEY (trigger_envelope_id) REFERENCES public.envelope(id);


--
-- Name: route route_process_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route
    ADD CONSTRAINT route_process_id_fkey FOREIGN KEY (process_id) REFERENCES public.process(id) ON DELETE CASCADE;


--
-- Name: route_target route_target_actor_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route_target
    ADD CONSTRAINT route_target_actor_id_fkey FOREIGN KEY (actor_id) REFERENCES public.actor(id);


--
-- Name: route_target route_target_route_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.route_target
    ADD CONSTRAINT route_target_route_id_fkey FOREIGN KEY (route_id) REFERENCES public.route(id) ON DELETE CASCADE;


--
-- PostgreSQL database dump complete
--
